<?php
// ===================
// Kalenderblatt 2025
// Dieses Script und alle zugehörigen Dateien im Ordner "kalenderdaten" unterliegen dem Urheberrecht S.G.Schiffer 2025 - sgs-visual.de
// Die Dateien dürfen weder zum Verkauf noch zum Herunterladen von anderen Webseiten als sgs-visual.de angeboten werden.
// Sie erhalten ein kostenloses Nutzungsrecht, was aber nicht bedeutet, das die Dateien damit in Ihr Eigentum übergehen.
// Die Copyright-Informationen dürfen nicht verändert oder gelöscht werden.
// ===================

// Bundesland für Feiertagsanzeige (bitte Ihr eigenes Bundesland aus folgende Zeile kopieren und in Zeile 13, wie gezeigt, einfügen):
// Baden-Württemberg, Bayern, Berlin, Brandenburg, Bremen, Hamburg, Hessen, Mecklenburg-Vorpommern, Niedersachsen, Nordrhein-Westfalen, Rheinland-Pfalz, Saarland, Sachsen, Sachsen-Anhalt, Schleswig-Holstein, Thüringen, Augsburg

$bundesland = "Hessen"; // <<< HIER Ihr Bundesland einfügen (z.B.:  $bundesland = "Hessen"; )

// Koordinaten für Sonnenauf-/untergang (Wiesbaden) bitte an Ihren Wohnort anpassen
$breitengrad = 50.0463333;
$laengengrad = 8.1976777;

// Mondphasen-Berechnung einbinden
require_once __DIR__ . '/kalenderdaten/mondphasen.php';

// Feiertage laden - Feiertag baserend auf der Feiertags-API von sgs-visual.de 2025-2045
$feiertage_json = file_get_contents(__DIR__ . '/kalenderdaten/feiertage.json');
$feiertage_data = json_decode($feiertage_json, true);

// Aktuelles Datum
$now = new DateTime('now', new DateTimeZone('Europe/Berlin'));
$heute = $now->format('d.m.Y');
$heute_kurz = $now->format('d.m');
$jahr = $now->format('Y');
$monat = $now->format('n');
$tag = (int)$now->format('j');

// Kalenderwoche
$kalenderwoche = (int)$now->format('W');

// Tageszahl im Jahr
$tag_im_jahr = (int)$now->format('z') + 1;

// Mondphase (String) - hier Anpassung für Vollmond und Neumond mit vollständigem Begriff
function getMoonPhaseStringFull($timestamp) {
    $phase = getMoonPhaseString($timestamp);
    $phaseLower = strtolower($phase);
    if (strpos($phaseLower, 'vollmond') !== false || $phaseLower === 'voll') {
        return 'Vollmond';
    }
    if (strpos($phaseLower, 'neumond') !== false || $phaseLower === 'neu') {
        return 'Neumond';
    }
    return $phase;
}
$mondphase = getMoonPhaseStringFull($now->getTimestamp());

// Sonnenaufgang/-untergang
$sun_info = date_sun_info($now->getTimestamp(), $breitengrad, $laengengrad);
$sonnenaufgang = date('H:i', $sun_info['sunrise']);
$sonnenuntergang = date('H:i', $sun_info['sunset']);

// Jahreszeiten bestimmen
function getJahreszeit($now) {
    $jahr = $now->format('Y');
    $zeiten = [
        ['von'=>"$jahr-01-01", 'bis'=>"$jahr-03-19", 'text'=>"Winter 21.12. - 19.03."],
        ['von'=>"$jahr-03-20", 'bis'=>"$jahr-06-20", 'text'=>"Frühling 20.03. - 20.06."],
        ['von'=>"$jahr-06-21", 'bis'=>"$jahr-09-22", 'text'=>"Sommer 21.06. - 22.09."],
        ['von'=>"$jahr-09-23", 'bis'=>"$jahr-12-20", 'text'=>"Herbst 23.09. - 20.12."],
        ['von'=>"$jahr-12-21", 'bis'=>"$jahr-12-31", 'text'=>"Winter 21.12. - 19.03."],
    ];
    $timestamp = $now->getTimestamp();
    foreach ($zeiten as $z) {
        $von = strtotime($z['von']);
        $bis = strtotime($z['bis']) + 86399;
        if ($timestamp >= $von && $timestamp <= $bis) {
            return $z['text'];
        }
    }
    return '';
}
$jahreszeit = getJahreszeit($now);

// Feiertag/Sonstiger Tag aus der JSON-Datei bestimmen
$heute_feiertag = '';
$heute_sonstiger = '';
$feiertage = [];
$sonstige_tage = [];
if (isset($feiertage_data['years'][$jahr])) {
    $feiertage = $feiertage_data['years'][$jahr]['holidays'];
    $sonstige_tage = $feiertage_data['years'][$jahr]['other_days'];
}
if (!empty($feiertage)) {
    foreach ($feiertage as $h) {
        if ($h['date'] === $heute) {
            if (in_array('all', $h['states']) || in_array($bundesland, $h['states'])) {
                $heute_feiertag = $h['name'];
                break;
            }
        }
    }
}
if (!$heute_feiertag && !empty($sonstige_tage)) {
    foreach ($sonstige_tage as $o) {
        if ($o['date'] === $heute) {
            $heute_sonstiger = $o['name'];
            break;
        }
    }
}

// Monatsname für die Ausgabe
$monate = [
    1=>"Januar",2=>"Februar",3=>"März",4=>"April",5=>"Mai",6=>"Juni",
    7=>"Juli",8=>"August",9=>"September",10=>"Oktober",11=>"November",12=>"Dezember"
];
$monat_name = $monate[$monat];

// Sternzeichen bestimmen
function getSternzeichen($now) {
    $jahr = $now->format('Y');
    $sternzeichen = [
        ['von'=>"$jahr-01-01", 'bis'=>"$jahr-01-20", 'name'=>"Steinbock", 'zeit'=>"21.12. - 20.01."],
        ['von'=>"$jahr-01-21", 'bis'=>"$jahr-02-19", 'name'=>"Wassermann", 'zeit'=>"21.01. - 19.02."],
        ['von'=>"$jahr-02-20", 'bis'=>"$jahr-03-20", 'name'=>"Fische", 'zeit'=>"20.02. - 20.03."],
        ['von'=>"$jahr-03-21", 'bis'=>"$jahr-04-20", 'name'=>"Widder", 'zeit'=>"21.03. - 20.04."],
        ['von'=>"$jahr-04-21", 'bis'=>"$jahr-05-20", 'name'=>"Stier", 'zeit'=>"21.04. - 20.05."],
        ['von'=>"$jahr-05-21", 'bis'=>"$jahr-06-21", 'name'=>"Zwilling", 'zeit'=>"21.05. - 21.06."],
        ['von'=>"$jahr-06-22", 'bis'=>"$jahr-07-22", 'name'=>"Krebs", 'zeit'=>"22.06. - 22.07."],
        ['von'=>"$jahr-07-23", 'bis'=>"$jahr-08-24", 'name'=>"Löwe", 'zeit'=>"23.07. - 24.08."],
        ['von'=>"$jahr-08-25", 'bis'=>"$jahr-09-23", 'name'=>"Jungfrau", 'zeit'=>"25.08. - 23.09."],
        ['von'=>"$jahr-09-24", 'bis'=>"$jahr-10-23", 'name'=>"Waage", 'zeit'=>"24.09. - 23.10."],
        ['von'=>"$jahr-10-24", 'bis'=>"$jahr-11-22", 'name'=>"Skorpion", 'zeit'=>"24.10. - 22.11."],
        ['von'=>"$jahr-11-23", 'bis'=>"$jahr-12-21", 'name'=>"Schütze", 'zeit'=>"23.11. - 21.12."],
        ['von'=>"$jahr-12-22", 'bis'=>"$jahr-12-31", 'name'=>"Steinbock", 'zeit'=>"22.12. - 20.01."],
    ];
    $timestamp = $now->getTimestamp();
    foreach ($sternzeichen as $sz) {
        $von = strtotime($sz['von']);
        $bis = strtotime($sz['bis']) + 86399;
        if ($timestamp >= $von && $timestamp <= $bis) {
            return "<b>{$sz['name']}</b> <span style='font-weight:normal;'>({$sz['zeit']})</span>";
        }
    }
    return '';
}
$sternzeichen = getSternzeichen($now);

// Wochentag (ohne strftime) in deutschen Wochentag übersetzen
setlocale(LC_TIME, 'de_DE.UTF-8'); // optional, falls Locale unterstützt wird
$wochentag_en = $now->format('l');
$wochentage = [
    'Monday'=>'Montag','Tuesday'=>'Dienstag','Wednesday'=>'Mittwoch','Thursday'=>'Donnerstag',
    'Friday'=>'Freitag','Saturday'=>'Samstag','Sunday'=>'Sonntag'
];
$wochentag = $wochentage[$wochentag_en] ?? $wochentag_en;

// Für die Tageszahl die Farbe bestimmen (rot oder schwarz)
// Änderung: Sonntage (#FF0000), Feiertage (#FF0000), sonst schwarz (#000)
$tag_farbe = "#000";
if ($heute_feiertag || $wochentag_en === 'Sunday') {
    $tag_farbe = "#FF0000";
}

// Feiertage/Sonstiger Tage Ausgabe
$feiertag_ausgabe = "";
if ($heute_feiertag) {
    $feiertag_ausgabe = "<span style='color:#FF0000;font-weight:bold;font-size:12px;'>$heute_feiertag</span>";
} elseif ($heute_sonstiger) {
    $feiertag_ausgabe = "<span style='color:#EB7D29;font-weight:600;font-size:12px;'>$heute_sonstiger</span>";
} else {
    $feiertag_ausgabe = "<span style='font-size:12px;'>&nbsp;</span>";
}

// Funktion zur Bestimmung des Mondphasen-Typs für Canvas (abnehmend, zunehmend, Vollmond - voll, Neumond - neu)
function getMoonPhaseType($timestamp) {
    $phaseStr = strtolower(getMoonPhaseString($timestamp));
    if (strpos($phaseStr, 'neumond') !== false || strpos($phaseStr, 'neu') !== false) {
        return 'new';
    } elseif (strpos($phaseStr, 'vollmond') !== false || strpos($phaseStr, 'voll') !== false) {
        return 'full';
    } elseif (strpos($phaseStr, 'zun') !== false) { // "zun. Mond"
        return 'waxing';
    } elseif (strpos($phaseStr, 'abn') !== false) { // "abn. Mond"
        return 'waning';
    }
    return 'new'; // Fallback
}
$mondphase_type = getMoonPhaseType($now->getTimestamp());
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="utf-8">
    <title>Kalenderblatt</title>
    <link rel="icon" type="image/x-icon" href="kalenderdaten/favicon.ico">
    <meta name="author" content="S.G.Schiffer">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <style>
    .kalender-canvas {
        width: 200px;
        max-width: 98vw;
        height: 260px;
        background: #fff;
        border: 1px solid #555;
        border-radius: 2px;
        box-shadow: 0 2px 12px #bbb;
        margin: 0 auto;
        font-family: Arial, sans-serif;
        display: flex;
        flex-direction: column;
        overflow: hidden;
    }
    .kalender-header {
        background: linear-gradient(90deg, #2C79DC 0%, #4F9DFE 100%);
        color: #fff;
        font-family: Tahoma, sans-serif;
        font-size: 1.3rem;
        font-weight: 600;
        text-align: center;
        padding: 12px 0 8px 0;
        letter-spacing: 1px;
    }
    .kalender-body {
        background: #fff;
        flex: 1 1 auto;
        display: flex;
        flex-direction: column;
        align-items: center;
        padding: 0 0 0 0;
    }
    .kalender-zeile {
        width: 100%;
        text-align: center;
        margin: 0;
        padding: 0;
    }
    .kalender-info {
        font-size: 8px;
        color: #222;
        margin-top: 6px;
        margin-bottom: 0;
        letter-spacing: 0.5px;
        display: flex;
        justify-content: center;
        align-items: center;
        gap: 6px;
    }
    .kalender-sonne {
        font-size: 8px;
        color: #000;
        margin: 2px 0 0 0;
    }
    .kalender-jahreszeit {
        font-size: 8px;
        color: #000;
        margin: 2px 0 0 0;
    }
    .kalender-tag {
        font-size: 75px;
        font-weight: 600;
        margin: 8px 0 0 0;
        color: <?= $tag_farbe ?>;
        line-height: 1;
    }
    .kalender-feiertag {
        margin: 2px 0 0 0;
        min-height: 18px;
    }
    .kalender-monatjahr {
        font-size: 16px;
        color: #222;
        margin: 2px 0 0 0;
        font-weight: 700;
    }
    .kalender-sternzeichen {
        font-size: 8px;
        color: #000;
        margin: 2px 0 0 0;
    }
    .kalender-footer {
        font-size: 8px;
        color: #000;
        margin-top: 10px;
        margin-left: 40px;
        margin-bottom: 0;
        display: flex;
        justify-content: space-between;
        align-items: center;
        width: 96%;
    }
    .kalender-footer a {
        color: #FF0000;
        text-decoration: none;
        font-weight: bold;
        font-size: 8px;
    }
    .kalender-info-btn {
        background: none;
        border: none;
        padding: 0;
        margin-right:30px;
        cursor: pointer;
        vertical-align: middle;
    }
    .kalender-info-btn img {
        width: 12px;
        height: 12px;
        display: inline-block;
    }
    @media (max-width: 300px) {
        .kalender-canvas { width: 98vw; height: 260px; }
    }
    </style>
    <script src="kalenderdaten/jquery-3.6.0.min.js"></script>
</head>
<body>
<div class="kalender-canvas">
    <div class="kalender-header"><?= htmlspecialchars($wochentag) ?></div>
    <div class="kalender-body">
        <div class="kalender-zeile kalender-info">
            KW <?= $kalenderwoche ?> | Tag <?= $tag_im_jahr ?> | <?= htmlspecialchars($mondphase) ?>
            <canvas id="mondCanvas" width="14" height="14" style="margin-left:4px; vertical-align:middle;"></canvas>
        </div>
        <div class="kalender-zeile kalender-sonne">
            SA: <?= $sonnenaufgang ?> / SU: <?= $sonnenuntergang ?>
        </div>
        <div class="kalender-zeile kalender-jahreszeit">
            <?= htmlspecialchars($jahreszeit) ?>
        </div>
        <div class="kalender-zeile kalender-tag">
            <?= $tag ?>
        </div>
        <div class="kalender-zeile kalender-feiertag">
            <?= $feiertag_ausgabe ?>
        </div>
        <div class="kalender-zeile kalender-monatjahr">
            <?= $monat_name . " " . $jahr ?>
        </div>
        <div class="kalender-zeile kalender-sternzeichen">
            <?= $sternzeichen ?>
        </div>
        <div class="kalender-footer">
            <span>
                &copy; S.G.Schiffer 2025
                <a href="https://www.sgs-visual.de/einfaches_kalenderblatt.php" target="_blank">sgs-visual.de</a>
            </span>
            <button class="kalender-info-btn" id="hilfeButton" title="Hilfe">
                <img src="kalenderdaten/info_button.png" alt="Information">
            </button>
        </div>
    </div>
</div>
<!-- Info-Dialog -->
<script>
function showExplanationDialog() {
    $('.custom-dialog-overlay, .custom-dialog-box').remove();
    var dialogHtml = `
        <div class="custom-dialog-overlay" style="position:fixed;top:0;left:0;right:0;bottom:0;background:rgba(0,0,0,0.3);z-index:9998;display:none;"></div>
        <div class="custom-dialog-box" role="dialog" aria-modal="true" aria-labelledby="customDialogHeader"
            style="position:fixed;top:50%;left:50%;transform:translate(-50%,-50%);background:#fff;border-radius:6px;min-width:0;width:90vw;max-width:400px;box-shadow:0 8px 32px rgba(0,0,0,0.25);z-index:9999;display:none;font-family:Arial,sans-serif;">
            <div class="custom-dialog-header" id="customDialogHeader" style="background:#2C79DC;color:#fff;font-size:1rem;font-weight:600;padding:12px 18px;border-radius:6px 6px 0 0;">
                Abkürzungen
            </div>
            <div class="custom-dialog-content" style="background:#fff;color:#000;font-size:0.95rem;padding:18px;border-radius:0 0 6px 6px;border-bottom:1px solid #eee;word-break:break-word;">
                <b>KW:</b> Kalenderwoche<br>
                <b>MP:</b> Aktuelle Mondphase in Prozent<br>
                <b>abn. Mond:</b> abnehmender Mond<br>
                <b>zun. Mond:</b> zunehmender Mond<br>
                <b>SA:</b> Sonnenaufgang<br>
                <b>SU:</b> Sonnenuntergang<br>
                <b>Sternz.:</b> Aktuelles Sternzeichen<br><br>
                <sub>&copy; S.G.Schiffer - <a class="Link" href="https://www.sgs-visual.de/einfaches_kalenderblatt.php" target="_blank" style="color:#FF0000;text-decoration:none;">sgs-visual.de</a> [Stand: 18.06.2025]</sub>
            </div>
            <div class="custom-dialog-footer" style="text-align:right;background:#fff;border-radius:0 0 6px 6px;padding:10px 18px 14px 18px;">
                <button class="custom-dialog-ok-btn" type="button" style="background:#000;color:#fff;font-size:1rem;font-weight:600;border:none;border-radius:4px;padding:7px 22px;cursor:pointer;">OK</button>
            </div>
        </div>
    `;
    $('body').append(dialogHtml);
    $('.custom-dialog-overlay, .custom-dialog-box').fadeIn(120);
    $('.custom-dialog-ok-btn, .custom-dialog-overlay').on('click', function() {
        $('.custom-dialog-overlay, .custom-dialog-box').fadeOut(120, function() {
            $('.custom-dialog-overlay, .custom-dialog-box').remove();
        });
    });
    $('.custom-dialog-ok-btn').focus();
}
$(function() {
    $('#hilfeButton').on('click', function() {
        showExplanationDialog();
    });

    var mondphaseType = '<?= $mondphase_type ?>';

    var canvas = document.getElementById('mondCanvas');
    if (canvas && canvas.getContext) {
        var ctx = canvas.getContext('2d');
        var w = canvas.width;
        var h = canvas.height;
        var centerX = w / 2;
        var centerY = h / 2;
        var radius = 6;

        // Hintergrundkreis (Mondscheibe) immer zeichnen: #333 mit schwarzem Rand
        ctx.fillStyle = '#333';
        ctx.strokeStyle = '#000';
        ctx.lineWidth = 2;
        ctx.beginPath();
        ctx.arc(centerX, centerY, radius, 0, Math.PI * 2);
        ctx.fill();
        ctx.stroke();

        // Mondsichel zeichnen (außer Neumond)
        if (mondphaseType !== 'new') {
            ctx.fillStyle = '#FFB400';
            ctx.beginPath();

            if (mondphaseType === 'full') {
                ctx.arc(centerX, centerY, radius, 0, Math.PI * 2);
                ctx.fill();
            } else if (mondphaseType === 'waxing') {
                ctx.arc(centerX + 2, centerY, radius, 0, Math.PI * 2);
                ctx.fill();

                ctx.fillStyle = '#333';
                ctx.beginPath();
                ctx.arc(centerX - 2, centerY, radius, 0, Math.PI * 2);
                ctx.fill();
            } else if (mondphaseType === 'waning') {
                ctx.arc(centerX - 2, centerY, radius, 0, Math.PI * 2);
                ctx.fill();

                ctx.fillStyle = '#333';
                ctx.beginPath();
                ctx.arc(centerX + 2, centerY, radius, 0, Math.PI * 2);
                ctx.fill();
            }
        }
    }
});
</script>
</body>
</html>