<?php
// Mondphasen-Berechnung (reduziert auf Prozent und Kurztext, ohne Nachkommastellen)

// Astronomische Konstanten
define('EPOCH', 2444238.5);
define('ELONGE', 278.833540);
define('ELONGP', 282.596403);
define('ECCENT', 0.016718);
define('MMLONG', 64.975464);
define('MMLONGP', 349.383063);
define('MLNODE', 151.950429);
define('MINC', 5.145396);
define('MECC', 0.054900);
define('MSMAX', 384401.0);
define('SYNMONTH', 29.53058868);

// Hilfsfunktionen
function fixangle($a) { return $a - 360.0 * floor($a / 360.0); }
function torad($a) { return $a * (pi() / 180.0); }
function kepler($m, $ecc) {
    $EPSILON = 1e-6;
    $m = torad($m);
    $e = $m;
    do {
        $delta = $e - $ecc * sin($e) - $m;
        $e -= $delta / (1 - $ecc * cos($e));
    } while (abs($delta) > $EPSILON);
    return $e;
}
function jtime($timestamp) {
    return ($timestamp / 86400) + 2440587.5;
}

// Hauptfunktion: Gibt die Mondphasen-Ausgabe als String zurck
function getMoonPhaseString($timestamp = null) {
    if ($timestamp === null) $timestamp = time();
    $pdate = jtime($timestamp);

    // Sonne
    $Day = $pdate - EPOCH;
    $N = fixangle((360 / 365.2422) * $Day);
    $M = fixangle($N + ELONGE - ELONGP);
    $Ec = kepler($M, ECCENT);
    $Ec = sqrt((1 + ECCENT) / (1 - ECCENT)) * tan($Ec / 2);
    $Ec = 2 * (180.0 / pi()) * atan($Ec);
    $Lambdasun = fixangle($Ec + ELONGP);

    // Mond
    $ml = fixangle(13.1763966 * $Day + MMLONG);
    $MM = fixangle($ml - 0.1114041 * $Day - MMLONGP);
    $MN = fixangle(MLNODE - 0.0529539 * $Day);
    $Ev = 1.2739 * sin(torad(2 * ($ml - $Lambdasun) - $MM));
    $Ae = 0.1858 * sin(torad($M));
    $A3 = 0.37 * sin(torad($M));
    $MmP = $MM + $Ev - $Ae - $A3;
    $mEc = 6.2886 * sin(torad($MmP));
    $A4 = 0.214 * sin(torad(2 * $MmP));
    $lP = $ml + $Ev + $mEc - $Ae + $A4;
    $V = 0.6583 * sin(torad(2 * ($lP - $Lambdasun)));
    $lPP = $lP + $V;

    // Mondalter in Grad
    $MoonAge = fixangle($lPP - $Lambdasun);

    // Mondphase als Prozent (ohne Nachkommastellen)
    $MoonPhase = (1 - cos(torad($MoonAge))) / 2;
    $percent = round($MoonPhase * 100); // <- HIER: keine Nachkommastellen

    // Krzel und Ausgabe
    if ($percent < 1) {
        $out = "Neumond {$percent}%";
    } elseif ($percent > 99) {
        $out = "Vollmond {$percent}%";
    } elseif ($MoonAge < 180) {
        $out = "zun. Mond {$percent}%";
    } else {
        $out = "abn. Mond {$percent}%";
    }
    return $out;
}
?>
